@@ -72,7 +72,7 @@ BadGey <- local({
            #
            return(list(param=list(gammas=gammas),
                        inames="interaction parameters gamma_i",
-                       printable=round(gn,4)))
+                       printable=dround(gn)))
          },
         valid = function(coeffs, self) {
            # interaction parameters gamma must be
@@ -196,6 +196,8 @@ BadGey <- local({
     instantiate.interact(BlankBG, list(r=r, sat=sat))
   }
 
+  BadGey <- intermaker(BadGey, BlankBG)
+  
   BadGey
 
 })
