@@ -1,6 +1,7 @@
-# Dominic Schuhmacher's idea
+#' Dominic Schuhmacher's idea
 
-clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NULL, hook=NULL) {
+clickppp <- function(n=NULL, win=square(1), types=NULL, ...,
+                     add=FALSE, main=NULL, hook=NULL) {
 
   win <- as.owin(win)
 
@@ -13,7 +14,7 @@ clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NUL
   
   ####  single type #########################
   if(is.null(types)) {
-    plot(win, add=add, main=main)
+    plot(win, add=add, main=main, invert=TRUE)
     if(!is.null(hook))
       plot(hook, add=TRUE)
     if(!is.null(n))
@@ -29,7 +30,7 @@ clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NUL
       warning(paste(nout,
                     ngettext(nout, "point", "points"),
                     "lying outside specified window; window was expanded"))
-      win <- bounding.box(win, bounding.box.xy(xy))
+      win <- boundingbox(win, xy)
     }
     X <- ppp(xy$x, xy$y, window=win)
     return(X)
@@ -57,7 +58,7 @@ clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NUL
       # User has clicked outside original window.
       naughty <- TRUE
       # Use bounding box for simplicity
-      bb <- bounding.box(Xi$window, X$window)
+      bb <- boundingbox(Xi$window, X$window)
       X <- superimpose(X, Xi, W=bb)
     } 
   }
@@ -65,8 +66,8 @@ clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NUL
     if(!naughty)
       plot(X, main="Final pattern")
     else {
-      plot(X$window, main="Final pattern (in expanded window)")
-      plot(win, add=TRUE)
+      plot(X$window, main="Final pattern (in expanded window)", invert=TRUE)
+      plot(win, add=TRUE, invert=TRUE)
       plot(X, add=TRUE)
     }
   }
@@ -74,4 +75,5 @@ clickppp <- function(n=NULL, win=square(1), types=NULL, ..., add=FALSE, main=NUL
 
 }
 
+
   
