@@ -89,63 +89,76 @@ summary.fii <- function(object, ...) {
 }
 
 print.fii <- function(x, ...) {
-  tiny <- resolve.1.default("tiny", list(...), list(tiny=FALSE))
-  print(summary(x), brief=TRUE, tiny=tiny)
+  sx <- summary(x)
+  do.call(print.summary.fii,
+          resolve.defaults(list(x=sx, brief=TRUE), list(...)))
   return(invisible(NULL))
 }
 
-print.summary.fii <- function(x, ...) {
-  secret <- resolve.defaults(list(...),
-                             list(prefix="Interaction: ",
-                                  family=TRUE,
-                                  brief=FALSE,
-                                  tiny=FALSE))
-  if(secret$tiny) {
-    # use thumbnail if available
-    thumbnail <- x$thumbnail
-    if(!is.null(thumbnail)) {
-      cat(paste(thumbnail, "\n"))
-      return(invisible(NULL))
-    }
+print.summary.fii <- local({
+
+  #'  hide internal arguments
+  print.summary.fii <- function(x, ...) {
+    PrintIt(x, ...)
   }
-  brief <- secret$brief
-  if(!brief)
-    cat(secret$prefix)
-  if(x$poisson)
-    cat("Poisson process\n")
-  else {
-    print(x$interaction, family=secret$family, brief=TRUE)
-    if(!is.null(x$printable)) {
-      nvalues <- length(x$printable)
-      nheader <- length(x$header)
-      if(nvalues == 1) {
-        cat(paste(x$header, ":\t", x$printable, "\n", sep=""))
-      } else if(nvalues == nheader) {
-        for(i in 1:nheader) {
-          cat(x$header[i])
-          xpi <- x$printable[[i]]
-          if(!is.list(xpi) && length(xpi) == 1) {
-            cat(":\t", xpi, "\n")
-          } else {
-            cat(":\n")
-            print(xpi)
-          }
+  
+  PrintIt <- function(x, ..., prefix="Interaction: ",
+                      banner=TRUE,
+                      family = waxlyrical('extras'),
+                      brief = !family,
+                      tiny = !waxlyrical('errors')) {
+    if(tiny) {
+      #' use thumbnail if available
+      thumbnail <- x$thumbnail
+      if(!is.null(thumbnail)) {
+        splat(thumbnail)
+        return(invisible(NULL))
+      }
+    }
+    terselevel <- spatstat.options('terse')
+    if(banner && !brief)
+      cat(prefix)
+    if(x$poisson) {
+      splat("Poisson process")
+      parbreak(terselevel)
+    } else {
+      print(x$interaction, family=family, brief=TRUE, banner=banner)
+      if(!is.null(x$printable)) {
+        nvalues <- length(x$printable)
+        nheader <- length(x$header)
+        if(nvalues == 1) {
+          splat(paste(paste0(x$header, ":\t"), x$printable))
+        } else if(nvalues == nheader) {
+          for(i in 1:nheader) {
+            hdi <- x$header[i]
+            xpi <- x$printable[[i]]
+            if(!is.list(xpi) && length(xpi) == 1) {
+              splat(paste0(hdi, ":\t", xpi))
+            } else {
+              splat(paste0(hdi, ":"))
+              print(xpi)
+            }
+          } 
+        } else {
+          splat(x$header)
+          print(x$printable)
         } 
-      } else {
-        cat(paste(x$header, ":\n", sep=""))
-        print(x$printable)
-      } 
+      }
     }
-  }
-  if(!brief) {
-    co <- x$coefs[x$Vnames[!x$IsOffset]]
-    if(length(co) > 0) {
-      cat("\nRelevant coefficients:\n")
-      print(co)
+    if(!brief) {
+      co <- x$coefs[x$Vnames[!x$IsOffset]]
+      if(length(co) > 0) {
+        parbreak(terselevel)
+        splat("Relevant coefficients:")
+        print(co)
+      }
     }
+    return(invisible(NULL))
   }
-  return(invisible(NULL))
-}
+
+  print.summary.fii
+})
+
 
 coef.summary.fii <- function(object, ...) {
   object$printable
@@ -178,11 +191,12 @@ reach.fii <- function(x, ..., epsilon=0) {
 }
 
 plot.fii <- function(x, ...) {
-  if(is.poisson.interact(x$interaction)) {
+  inte <- x$interaction
+  if(is.poisson.interact(inte)) {
     message("Poisson interaction; nothing plotted")
     return(invisible(NULL))
   }
-  plfun <- x$interaction$family$plot
+  plfun <- inte$plot %orifnull% inte$family$plot
   if(is.null(plfun)) 
     stop("Plotting not implemented for this type of interaction")
   plfun(x, ...)
@@ -208,6 +222,7 @@ fitin.ppm <- function(object) {
     # Internal names of regressor variables 
     f <- fii(inte, coefs, Vnames, IsOffset)
   }
+  unitname(f) <- unitname(data.ppm(object))
   return(f)
 }
 
