@@ -1,102 +1,126 @@
-#
-#
-#     markcorr.R
-#
-#     $Revision: 1.65 $ $Date: 2014/10/08 10:47:28 $
-#
-#    Estimate the mark correlation function
-#    and related functions 
-#    
-# ------------------------------------------------------------------------
+##
+##
+##     markcorr.R
+##
+##     $Revision: 1.69 $ $Date: 2014/11/10 10:58:11 $
+##
+##    Estimate the mark correlation function
+##    and related functions 
+##    
+## ------------------------------------------------------------------------
 
-"markvario" <-
-function(X, correction=c("isotropic", "Ripley", "translate"),
-         r=NULL, method="density", ..., normalise=FALSE) {
-  m <- onecolumn(marks(X))
-  if(!is.numeric(m))
-    stop("Marks are not numeric")
-  if(missing(correction))
-    correction <- NULL
-  # Compute estimates
-  v <- markcorr(X, f=function(m1, m2) { (1/2) * (m1-m2)^2 },
-                r=r, correction=correction, method=method,
-                normalise=normalise, ...)
-  # adjust theoretical value
-  v$theo <- if(normalise) 1 else var(m)    
-  # fix labels
-  v <- rebadge.fv(v,
-                  quote(gamma(r)),
-                  "gamma")
-  return(v)
-}
+markvario <- local({
+
+  halfsquarediff <- function(m1, m2) { ((m1-m2)^2)/2 }
+
+  markvario <- 
+    function(X, correction=c("isotropic", "Ripley", "translate"),
+             r=NULL, method="density", ..., normalise=FALSE) {
+      m <- onecolumn(marks(X))
+      if(!is.numeric(m))
+        stop("Marks are not numeric")
+      if(missing(correction))
+        correction <- NULL
+      ## Compute estimates
+      v <- markcorr(X, f=halfsquarediff, 
+                    r=r, correction=correction, method=method,
+                    normalise=normalise, ...)
+      ## adjust theoretical value
+      v$theo <- if(normalise) 1 else var(m)    
+      ## fix labels
+      v <- rebadge.fv(v,
+                      quote(gamma(r)),
+                      "gamma")
+      return(v)
+    }
+
+  markvario
+})
+
+markconnect <- local({
 
-markconnect <-
-function(X, i, j, r=NULL, 
-         correction=c("isotropic", "Ripley", "translate"),
-         method="density", ..., normalise=FALSE) {
-  stopifnot(is.ppp(X) && is.multitype(X))
-  if(missing(correction))
-    correction <- NULL
-  marx <- marks(X)
-  lev  <- levels(marx)
-  if(missing(i)) i <- lev[1]
-  if(missing(j)) j <- lev[2]
   indicateij <- function(m1, m2, i, j) { (m1 == i) & (m2 == j) }
-  # compute estimates
-  p <- markcorr(X, f=indicateij, r=r,
-                correction=correction, method=method,
-                ...,
-                fargs=list(i=i, j=j),
-                normalise=normalise)
-  # alter theoretical value and fix labels
-  if(!normalise) {
-    pipj <- mean(marx==i) * mean(marx==j) 
-    p$theo <- pipj
-  } else {
-    p$theo <- 1
+  
+  markconnect <- function(X, i, j, r=NULL, 
+                          correction=c("isotropic", "Ripley", "translate"),
+                          method="density", ..., normalise=FALSE) {
+    stopifnot(is.ppp(X) && is.multitype(X))
+    if(missing(correction))
+      correction <- NULL
+    marx <- marks(X)
+    lev  <- levels(marx)
+    if(missing(i)) i <- lev[1]
+    if(missing(j)) j <- lev[2]
+    ## compute estimates
+    p <- markcorr(X, f=indicateij, r=r,
+                  correction=correction, method=method,
+                  ...,
+                  fargs=list(i=i, j=j),
+                  normalise=normalise)
+    ## alter theoretical value and fix labels
+    if(!normalise) {
+      pipj <- mean(marx==i) * mean(marx==j) 
+      p$theo <- pipj
+    } else {
+      p$theo <- 1
+    }
+    p <- rebadge.fv(p,
+                    new.ylab=substitute(p[i,j](r), list(i=paste(i),j=paste(j))),
+                    new.fname=c("p", paste0("list(", i, ",", j, ")")),
+                    new.yexp=substitute(p[list(i,j)](r),
+                      list(i=paste(i),j=paste(j))))
+    return(p)
   }
-  p <- rebadge.fv(p,
-                  new.ylab=substitute(p[i,j](r), list(i=paste(i),j=paste(j))),
-                  new.fname=c("p", paste0("list(", i, ",", j, ")")),
-                  new.yexp=substitute(p[list(i,j)](r),
-                                      list(i=paste(i),j=paste(j))))
-  return(p)
-}
+  markconnect
+})
 
-Emark <- function(X, r=NULL, 
-                  correction=c("isotropic", "Ripley", "translate"),
-                  method="density", ..., normalise=FALSE) {
-  stopifnot(is.ppp(X) && is.marked(X) && is.numeric(marks(X)))
-  if(missing(correction))
-    correction <- NULL
-  f <- function(m1, m2) { m1 }
-  E <- markcorr(X, f, r=r,
-                correction=correction, method=method,
-                ..., normalise=normalise)
-  E <- rebadge.fv(E, quote(E(r)), "E")
-  return(E)
-}
 
-Vmark <- function(X, r=NULL, 
-                  correction=c("isotropic", "Ripley", "translate"),
-                  method="density", ..., normalise=FALSE) {
-  if(missing(correction))
-    correction <- NULL
-  E <- Emark(X, r=r, correction=correction, method=method, ...,
-             normalise=FALSE)
+Emark <- local({
+
+  f1 <- function(m1, m2) { m1 }
+
+  Emark <- function(X, r=NULL, 
+                    correction=c("isotropic", "Ripley", "translate"),
+                    method="density", ..., normalise=FALSE) {
+    stopifnot(is.ppp(X) && is.marked(X) && is.numeric(marks(X)))
+    if(missing(correction))
+      correction <- NULL
+    E <- markcorr(X, f1, r=r,
+                  correction=correction, method=method,
+                  ..., normalise=normalise)
+    E <- rebadge.fv(E, quote(E(r)), "E")
+    return(E)
+  }
+
+  Emark
+})
+
+Vmark <- local({
+
   f2 <- function(m1, m2) { m1^2 }
-  E2 <- markcorr(X, f2, r=E$r,
-                 correction=correction, method=method,
-                 ..., normalise=FALSE)
-  V <- eval.fv(E2 - E^2)
-  if(normalise) {
-    sig2 <- var(marks(X))
-    V <- eval.fv(V/sig2)
+
+  Vmark <- function(X, r=NULL, 
+                    correction=c("isotropic", "Ripley", "translate"),
+                    method="density", ..., normalise=FALSE) {
+    if(missing(correction))
+      correction <- NULL
+    E <- Emark(X, r=r, correction=correction, method=method, ...,
+             normalise=FALSE)
+    E2 <- markcorr(X, f2, r=E$r,
+                   correction=correction, method=method,
+                   ..., normalise=FALSE)
+    V <- eval.fv(E2 - E^2)
+    if(normalise) {
+      sig2 <- var(marks(X))
+      V <- eval.fv(V/sig2)
+    }
+    V <- rebadge.fv(V, quote(V(r)), "V")
+    attr(V, "labl") <- attr(E, "labl")
+    return(V)
   }
-  V <- rebadge.fv(V, quote(V(r)), "V")
-  attr(V, "labl") <- attr(E, "labl")
-  return(V)
-}
+
+  Vmark
+})
 
 ############## workhorses 'markcorr' and 'markcorrint' ####################
 
@@ -104,22 +128,23 @@ markcorrint <-
   function(X, f=NULL, r=NULL, 
            correction=c("isotropic", "Ripley", "translate"), ...,
            f1=NULL, normalise=TRUE, returnL=FALSE, fargs=NULL) {
-  # Computes the analogue of Kest(X)
-  # where each pair (x_i,x_j) is weighted by w(m_i,m_j)
-  #
-  # If multiplicative=TRUE then w(u,v) = f(u) f(v)
-  # If multiplicative=FALSE then w(u,v) = f(u, v)
-  #
+  ## Computes the analogue of Kest(X)
+  ## where each pair (x_i,x_j) is weighted by w(m_i,m_j)
+  ##
+  ## If multiplicative=TRUE then w(u,v) = f(u) f(v)
+  ## If multiplicative=FALSE then w(u,v) = f(u, v)
+  ##
   stopifnot(is.ppp(X) && is.marked(X))
   is.marked(X, dfok=FALSE)
-  # validate test function
+  W <- Window(X)
+  ## validate test function
   h <- check.testfun(f, f1, X)
   f     <- h$f
   f1    <- h$f1
   ftype <- h$ftype
   multiplicative <- ftype %in% c("mul", "product")
-  # 
-  # check corrections
+  ## 
+  ## check corrections
   correction.given <- !missing(correction) && !is.null(correction)
   if(is.null(correction))
     correction <- c("isotropic", "Ripley", "translate")
@@ -134,6 +159,9 @@ markcorrint <-
                              translation="translate",
                              best="best"),
                            multi=TRUE)
+
+  correction <- implemented.for.K(correction, W$type, correction.given)
+
   isborder  <- correction %in% c("border", "bord.modif")
   if(any(isborder) && !multiplicative) {
     whinge <- paste("Border correction is not valid unless",
@@ -144,8 +172,8 @@ markcorrint <-
     else
       warning(whinge)
   }
-  # estimated intensity
-  lambda <- X$n/area(Window(X))
+  ## estimated intensity
+  lambda <- intensity(X)
   mX <- marks(X)
   switch(ftype,
          mul={
@@ -201,14 +229,14 @@ markcorr <-
            correction=c("isotropic", "Ripley", "translate"),
            method="density", ..., f1=NULL, normalise=TRUE, fargs=NULL)
 {
-  # mark correlation function with test function f
+  ## mark correlation function with test function f
   stopifnot(is.ppp(X) && is.marked(X))
   
-  # set defaults to NULL
+  ## set defaults to NULL
   if(missing(f)) f <- NULL
   if(missing(correction)) correction <- NULL
   
-  # handle data frame of marks
+  ## handle data frame of marks
   marx <- marks(X, dfok=TRUE)
   if(is.data.frame(marx)) {
     nc <- ncol(marx)
@@ -224,18 +252,18 @@ markcorr <-
     return(result)
   }
   
-  # validate test function
+  ## validate test function
   h <- check.testfun(f, f1, X)
   f     <- h$f
   f1    <- h$f1
   ftype <- h$ftype
-  #
-  # 
+  ##
+  ## 
   npts <- npoints(X)
   W <- X$window
 
   
-  # determine r values 
+  ## determine r values 
   rmaxdefault <- rmax.rule("K", W, npts/area(W))
   breaks <- handle.r.b.args(r, NULL, W, rmaxdefault=rmaxdefault)
   r <- breaks$r
@@ -247,7 +275,7 @@ markcorr <-
     stop(paste("Evenly spaced r values are required if method=",
                sQuote("density"), sep=""))
         
-  # available selection of edge corrections depends on window
+  ## available selection of edge corrections depends on window
   correction.given <- !missing(correction) && !is.null(correction)
   if(is.null(correction))
     correction <- c("isotropic", "Ripley", "translate")
@@ -264,9 +292,9 @@ markcorr <-
   
   correction <- implemented.for.K(correction, W$type, correction.given)
 
-  # Denominator
-  # Ef = Ef(M,M') when M, M' are independent
-  # Apply f to every possible pair of marks, and average
+  ## Denominator
+  ## Ef = Ef(M,M') when M, M' are independent
+  ## Apply f to every possible pair of marks, and average
   Ef <- switch(ftype,
                mul = {
                  mean(marx)^2
@@ -296,7 +324,7 @@ markcorr <-
   }
 
   if(normalise) {
-    # check validity of denominator
+    ## check validity of denominator
     if(Efdenom == 0)
       stop("Cannot normalise the mark correlation; the denominator is zero")
     else if(Efdenom < 0)
@@ -304,12 +332,12 @@ markcorr <-
                     "the denominator is negative"))
   }
   
-  # this will be the output data frame
+  ## this will be the output data frame
   result <- data.frame(r=r, theo= rep.int(theory,length(r)))
   desc <- c("distance argument r",
             "theoretical value (independent marks) for %s")
   alim <- c(0, min(rmax, rmaxdefault))
-  # determine conventional name of function
+  ## determine conventional name of function
   if(ftype %in% c("mul", "equ")) {
     if(normalise) {
       ylab <- quote(k[mm](r))
@@ -330,15 +358,15 @@ markcorr <-
   result <- fv(result, "r", ylab, "theo", , alim,
                c("r","{%s[%s]^{iid}}(r)"), desc, fname=fnam)
 
-  # find close pairs of points
+  ## find close pairs of points
   close <- closepairs(X, rmax)
   dIJ <- close$d
   I   <- close$i
   J   <- close$j
   XI <- ppp(close$xi, close$yi, window=W, check=FALSE)
 
-  # apply f to marks of close pairs of points
-  #
+  ## apply f to marks of close pairs of points
+  ##
   mI <- marx[I]
   mJ <- marx[J]
   ff <- switch(ftype,
@@ -361,7 +389,7 @@ markcorr <-
                    do.call(f, append(list(marx[I], marx[J]), fargs))
                })
 
-  # check values of f(M1, M2)
+  ## check values of f(M1, M2)
   
   if(is.logical(ff))
     ff <- as.numeric(ff)
@@ -385,10 +413,10 @@ markcorr <-
   #### Compute estimates ##############
         
   if(any(correction == "translate")) {
-    # translation correction
+    ## translation correction
     XJ <- ppp(close$xj, close$yj, window=W, check=FALSE)
     edgewt <- edge.Trans(XI, XJ, paired=TRUE)
-    # get smoothed estimate of mark covariance
+    ## get smoothed estimate of mark covariance
     Mtrans <- sewsmod(dIJ, ff, edgewt, Efdenom, r, method, ...)
     result <- bind.fv(result,
                       data.frame(trans=Mtrans), "{hat(%s)[%s]^{trans}}(r)",
@@ -396,38 +424,38 @@ markcorr <-
                       "trans")
   }
   if(any(correction == "isotropic")) {
-    # Ripley isotropic correction
+    ## Ripley isotropic correction
     edgewt <- edge.Ripley(XI, matrix(dIJ, ncol=1))
-    # get smoothed estimate of mark covariance
+    ## get smoothed estimate of mark covariance
     Miso <- sewsmod(dIJ, ff, edgewt, Efdenom, r, method, ...)
     result <- bind.fv(result,
                       data.frame(iso=Miso), "{hat(%s)[%s]^{iso}}(r)",
                       "Ripley isotropic correction estimate of %s",
                       "iso")
   }
-  # which corrections have been computed?
+  ## which corrections have been computed?
   nama2 <- names(result)
   corrxns <- rev(nama2[nama2 != "r"])
 
-  # default is to display them all
+  ## default is to display them all
   formula(result) <- (. ~ r)
   fvnames(result, ".") <- corrxns
-  #
+  ##
   unitname(result) <- unitname(X)
   return(result)
 }
 
 sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
-  # Smooth Estimate of Weighted Second Moment Density
-  # (engine for computing mark correlations, etc)
-  # ------
-  # Vectors containing one entry for each (close) pair of points
-  # d = interpoint distance
-  # ff = f(M1, M2) where M1, M2 are marks at the two points
-  # wt = edge correction weight
-  # -----
-  # Ef = E[f(M, M')] where M, M' are independent random marks
-  # 
+  ## Smooth Estimate of Weighted Second Moment Density
+  ## (engine for computing mark correlations, etc)
+  ## ------
+  ## Vectors containing one entry for each (close) pair of points
+  ## d = interpoint distance
+  ## ff = f(M1, M2) where M1, M2 are marks at the two points
+  ## wt = edge correction weight
+  ## -----
+  ## Ef = E[f(M, M')] where M, M' are independent random marks
+  ## 
   d <- as.vector(d)
   ff <- as.vector(ff)
   wt <- as.vector(wt)
@@ -436,12 +464,12 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
            fw <- ff * wt
            sum.fw <- sum(fw)
            sum.wt <- sum(wt)
-           # smooth estimate of kappa_f
+           ## smooth estimate of kappa_f
            est <- density(d, weights=fw/sum.fw,
                           from=min(rvals), to=max(rvals), n=length(rvals),
                           ...)$y
            numerator <- est * sum.fw
-           # smooth estimate of kappa_1
+           ## smooth estimate of kappa_1
            est0 <- density(d, weights=wt/sum.wt, 
                           from=min(rvals), to=max(rvals), n=length(rvals),
                           ...)$y
@@ -449,7 +477,7 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
            result <- numerator/denominator
          },
          sm={
-           # This is slow!
+           ## This is slow!
            oldopt <- options(warn=-1)
            smok <- require(sm)
            options(oldopt)
@@ -457,13 +485,13 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
              stop(paste("Option method=sm requires package sm,",
                         "which is not available"))
 
-           # smooth estimate of kappa_f
+           ## smooth estimate of kappa_f
            fw <- ff * wt
            est <- sm::sm.density(d, weights=fw,
                                  eval.points=rvals,
                                  display="none", nbins=0, ...)$estimate
            numerator <- est * sum(fw)/sum(est)
-           # smooth estimate of kappa_1
+           ## smooth estimate of kappa_1
            est0 <- sm::sm.density(d, weights=wt,
                                   eval.points=rvals,
                                   display="none", nbins=0, ...)$estimate
@@ -482,19 +510,19 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
            if(hstuff$hmult == 1 && all(is.na(hstuff$h.weights)))
              warning("default smoothing parameter may be inappropriate")
            
-           # use replication to effect the weights (it's faster)
+           ## use replication to effect the weights (it's faster)
            nw <- round(nwtsteps * wt/max(wt))
            drep.w <- rep.int(d, nw)
            fw <- ff * wt
            nfw <- round(nwtsteps * fw/max(fw))
            drep.fw <- rep.int(d, nfw)
 
-           # smooth estimate of kappa_f
+           ## smooth estimate of kappa_f
            est <- sm::sm.density(drep.fw,
                                  eval.points=rvals,
                                  display="none", ...)$estimate
            numerator <- est * sum(fw)/sum(est)
-           # smooth estimate of kappa_1
+           ## smooth estimate of kappa_1
            est0 <- sm::sm.density(drep.w,
                                   eval.points=rvals,
                                   display="none", ...)$estimate
@@ -502,15 +530,15 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
            result <- numerator/denominator
          },
          loess = {
-           # set up data frame
+           ## set up data frame
            df <- data.frame(d=d, ff=ff, wt=wt)
-           # fit curve to numerator using loess
+           ## fit curve to numerator using loess
            fitobj <- loess(ff ~ d, data=df, weights=wt, ...)
-           # evaluate fitted curve at desired r values
+           ## evaluate fitted curve at desired r values
            Eff <- predict(fitobj, newdata=data.frame(d=rvals))
-           # normalise:
-           # denominator is the sample mean of all ff[i,j],
-           # an estimate of E(ff(M1,M2)) for M1,M2 independent marks
+           ## normalise:
+           ## denominator is the sample mean of all ff[i,j],
+           ## an estimate of E(ff(M1,M2)) for M1,M2 independent marks
            result <- Eff/Ef
          },
          )
@@ -519,59 +547,64 @@ sewsmod <- function(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500) {
 
 ############## user interface bits ##################################
 
-check.testfun <- function(f=NULL, f1=NULL, X) {
-  # Validate f or f1 as a test function for point pattern X
-  # Determine function type 'ftype' ("mul", "equ", "product" or "general")
-
+check.testfun <- local({
+  
   fmul <- function(m1, m2) { m1 * m2 }
   fequ <- function(m1, m2) { m1 == m2 }
   f1id <- function(m) { m }
 
-  if(is.null(f) && is.null(f1)) {
-    # no functions given
-    # default depends on kind of marks
-    if(is.multitype(X)) {
-      f <- fequ
-      ftype <- "equ"
-    } else {
-      f1 <- f1id
-      ftype <- "mul"
-    }
-  } else if(!is.null(f1)) {
-    # f1 given
-    # specifies test function of the form f(u,v) = f1(u) f1(v)
-    if(!is.null(f))
-      warning("argument f ignored (overridden by f1)")
-    stopifnot(is.function(f1))
-    ftype <- "product"
-  } else {
-    # f given 
-    if(is.character(fname <- f)) {
-      switch(fname,
-           "mul"  = {
-             f1 <- f1id
-             ftype <- "mul"
-           },
-           "equ" = {
-             f <- fequ
-             ftype <- "equ"
-           },
-           {
-             f <- get(fname)
-             ftype <- "general"
-           })
-    } else if(is.function(f)) {
-      same <- function(f, g) {
-        environment(g) <- environment(f)
-        identical(f,g)
+  check.testfun <- function(f=NULL, f1=NULL, X) {
+    ## Validate f or f1 as a test function for point pattern X
+    ## Determine function type 'ftype'
+    ##      ("mul", "equ", "product" or "general")
+
+    if(is.null(f) && is.null(f1)) {
+      ## no functions given
+      ## default depends on kind of marks
+      if(is.multitype(X)) {
+        f <- fequ
+        ftype <- "equ"
+      } else {
+        f1 <- f1id
+        ftype <- "mul"
       }
-      ftype <- if(same(f, fmul)) "mul" else if(same(f, fequ)) "equ" else "general"
-      if(ftype == "mul" && is.multitype(X))
-        stop(paste("Inappropriate choice of function f;",
-                   "point pattern is multitype;",
-                   "types cannot be multiplied."))
-    } else
-    stop("Argument f must be a function or the name of a function")
+    } else if(!is.null(f1)) {
+      ## f1 given
+      ## specifies test function of the form f(u,v) = f1(u) f1(v)
+      if(!is.null(f))
+        warning("argument f ignored (overridden by f1)")
+      stopifnot(is.function(f1))
+      ftype <- "product"
+    } else {
+      ## f given 
+      if(is.character(fname <- f)) {
+        switch(fname,
+               "mul"  = {
+                 f1 <- f1id
+                 ftype <- "mul"
+               },
+               "equ" = {
+                 f <- fequ
+                 ftype <- "equ"
+               },
+               {
+                 f <- get(fname)
+                 ftype <- "general"
+               })
+      } else if(is.function(f)) {
+        ftype <- if(isTRUE(all.equal(f, fmul))) "mul" else
+                 if(isTRUE(all.equal(f, fequ))) "equ" else "general"
+        if(ftype == "mul" && is.multitype(X))
+          stop(paste("Inappropriate choice of function f;",
+                     "point pattern is multitype;",
+                     "types cannot be multiplied."))
+      } else
+        stop("Argument f must be a function or the name of a function")
+    }
+    return(list(f=f, f1=f1, ftype=ftype))
   }
-  return(list(f=f, f1=f1, ftype=ftype))
-}
+
+  check.testfun
+})
+
+
